# Part of Odoo. See LICENSE file for full copyright and licensing details.

from . import backend
from . import binary
from . import form
from . import main
from . import model_page
from . import webclient
